\name{BMMdiag}
\alias{BMMdiag}
\title{Plot Identifiability Diagnostics for jags Object}
\description{
  Two different plots are currently provided: a plot of different
  variables against each other and a plot of the same variable against
  its values in the other classes.
}
\usage{
BMMdiag(object, which = 1:2, variables, ask = interactive(), fct1,
        fct2, xlim, ylim, auto.layout = TRUE, caption = NULL,
        main = "", ...)
}

\arguments{
  \item{object}{a \code{jags} object with model of class \code{BMMmodel}.}
  \item{which}{if only one of the plots is required, specify its number.}
  \item{variables}{if \code{variables} is missing, the names are taken
    from the \code{jags} object.}
  \item{ask}{prompt user before each page of plots}
  \item{fct1}{string: name of transformation function for variable on x-axis.}
  \item{fct2}{string: name of transformation function for variable on y-axis.}
  \item{xlim}{if no range for \code{xlim} is specified, a sensible range is
    taken.}
  \item{ylim}{if no range for \code{ylim} is specified, a sensible range is
    taken.}
  \item{auto.layout}{logical: if \code{TRUE} puts each of the two
    different plots on one figure.}
  \item{caption}{captions to appear above the plots.}
  \item{main}{title to each plot (in addition to the above 'caption').}
  \item{...}{further graphical parameters (see 'plot.xy' and 'par') may
    also be supplied as arguments.}
}
      
\details{The plots help determining which variable will induce a unique
  labelling when taken for ordering of the segments and indicate if the
  model is overfitted by specifying too  many segments.
}
\author{Bettina Gruen}
\keyword{hplot}

\eof
\name{BMMmodel}
\alias{BMMmodel}
\alias{print.JAGSmodel}
\title{Creates text for .bug-file and data for -inits.R and
  -data.R-file} 
\description{
  Creates the text for the BUGS-model specification and the values of the
  initialization, prior specification and the observations read in by jags. 
}
\usage{
BMMmodel(y, k, priors, inits = "initsFS", aprioriWeights = 1,
         no.empty.classes = FALSE, restrict = "none", ...)
}
\arguments{
  \item{y}{a numeric vector.}
  \item{k}{integer indicating the number of segments.}
  \item{priors}{specification of priors by a named list or a
    \code{BMMpriors} object.}
  \item{inits}{specification of initial values by a named list or string
    indicating the function to be called.}
  \item{aprioriWeights}{specification of prior of the a-priori weights. If
    \code{aprioriWeights} does not have length = k, there is an equal
    prior for the a-priori weights assumed.}
  \item{no.empty.classes}{logical: should it be prevented that empty
    classes arise during sampling.}
  \item{restrict}{one of "none", "mu", "tau".}
  \item{...}{further parameters for the function specified in
    \code{inits}.} 
}
\details{By default the function \code{initsFS} is called for generating
  initial values. Any other function specified by \code{inits} is
  assumed to have at least \code{x}, \code{k} and \code{restrict} as
  input parameters.

  The parameter \code{restrict} indicates if a
  location-shift model ("tau"), a scale contaminated model
  ("mu") or a model where both variables vary over components shall
  be fitted.

  If the logical \code{no.empty.classes} is \code{TRUE} there
  are observations added to the model that the classes are not empty. This
  signifies that the likelihood when sampling the class affiliations is
  changed thus that any data point which is sampled and is the last one
  in its class stays there.  
}
\value{
  If \code{y} is specified there is an object of class \code{BMMmodel}
  returned with components:
  \item{inits}{named list for -inits.R-file.}
  \item{data}{named list for -data.R-file.}
  \item{bugs}{text for .bug-file with prefix missing.}

  If \code{y} is missing there is an object of class \code{BMMsetup}
  returned containing the parameter specifications. When \code{JAGSsetup}
  is called with this object as model argument, \code{BMMmodel} is
  called with \code{y} and the other parameters as input arguments
  before creating the input files for jags.
}
\author{Bettina Gruen}
\seealso{\code{\link{JAGSrun}}, \code{\link{initsFS}}}
\examples{
data(fish)
model <- BMMmodel(fish, k = 4, priors = list(kind = "independence",
                  parameter = "priorsFish", hierarchical = "tau"),
                  initialValues = list(S0 = 2))
model
}
\keyword{utilities}


\eof
\name{BMMposteriori}
\alias{BMMposteriori}
\title{Plots aposteriori probabilities of data points}
\description{
  Given a \code{jags} object with model of class \code{BMMmodel} the
  aposteriori probabilities are determined. If \code{plot=TRUE}, the
  resulting object of class \code{BMMposteriori} is plotted by calling
  \code{plot.BMMposteriori}.
}
\usage{
BMMposteriori(object, class, caption = NULL, plot = TRUE,
              auto.layout = TRUE, ...)
}
\arguments{
  \item{object}{a \code{jags} object with model of class \code{BMMmodel}.}
  \item{class}{a vector of integers indicating for which classes the
    posterior probabilities shall be plotted. The default is all.}
  \item{caption}{captions to appear above the plots.}
  \item{plot}{logical indicating if a plot shall be made.}
  \item{auto.layout}{logical: if \code{TRUE} puts all classes in the
    posterior probabilities plot on the same figure.}
  \item{\dots}{further graphical parameters may also be supplied as
    arguments.} 
}
\details{
  Given a \code{jags} object with model of class \code{BMMmodel} the a
  posteriori probabilities are calculated for the unique data points
  with respect to the components specified by \code{class}.
}
\value{
  There is a \code{BMMposteriori} object returned which is a list
  including the following components
  \item{data}{vector of unique data points.}
  \item{post}{a matrix including the posteriori probability of the data
    points for each class.} 
}
\author{Bettina Gruen}

\seealso{\code{\link{plot.BMMposteriori}}}
\keyword{hplot}


\eof
\name{BMMpriors}
\alias{BMMpriors}
\title{Creates a 'BMMpriors' object}
\description{This function enables a comfortable creation of
  \code{BMMpriors} objects, which can be used for specifying the priors 
  of a \code{BMMmodel}.
}
\usage{
BMMpriors(specification, y)
}
\arguments{
  \item{specification}{named list including \code{kind}, \code{parameter},
    \code{hierarchical} and \code{mod}.}
  \item{y}{a numeric vector.}
}
\details{In \code{specification} \code{kind} can be used for specifying
  if an "independent" or a "conditionallyconjugate"
  prior shall be used. \code{parameter} can be a named list of values for
  the prior variables or a function name (e.g., "priorsUncertain",
  "priorsFish", "priorsRaftery"). \code{hierarchical} can be \code{NULL}
  or "tau" if a hierarchical prior shall be taken for
  \eqn{\tau}. \code{mod} is a named list which provides the possibility
  to override the values from \code{parameter}. 
}
\value{
  There is an object \code{BMMpriors} returned with components
  \item{name}{vector indicating which kind of prior is specified and if
    it is an hierarchical prior and if appropriate with respect to which
    variable.}
  \item{var}{list of variables in the prior and their specified values.} 
}
\author{Bettina Gruen}
\examples{
  data(fish)
  priors <- BMMpriors(y = fish)
  }
\keyword{utilities}


\eof
\name{JAGScall}
\alias{JAGScall}
\title{Calls jags}
\description{
Given the \code{prefix} of the .cmd-file and the path to jags the program
jags is called in batch mode by inserting the .cmd-file.
}
\usage{
JAGScall(prefix, jags, quiet = FALSE)
}
\arguments{
  \item{prefix}{string: name of .cmd-file.}
  \item{jags}{string: path to jags.}
  \item{quiet}{logical indicating whether error messages should be ignored.}
}
\details{
  If \code{jags} is missing, it is assumed that the program
  jags is in the path such that it is called with jags.
}
\value{
  Returns the exit status.
}
\author{Bettina Gruen}
\seealso{\code{\link{JAGSrun}}}
\keyword{utilities}


\eof
\name{JAGScontrol}
\alias{JAGScontrol}
\alias{print.JAGScontrol}
\title{Creates text for .cmd file}
\description{
  Creates the text for the file where all the commands for jags are included.
}
\usage{
JAGScontrol(variables, draw = 1000, burnIn = 0, seed)
}
\arguments{
  \item{variables}{names of variables which shall be monitored.}
  \item{draw}{number of monitored draws.}
  \item{burnIn}{number of discarded burn-in draws.}
  \item{seed}{integer setting the seed for the RNG.}
}
\details{This function creates the text for the .cmd-file. It includes
  information on the number of burn-in draws and monitored
  draws. Furthermore, it states which variables shall be monitored and
  it possibly specifies a seed. The information on the prefix of the
  files containing model, data and initial value is missing. By
  inserting the prefix between the elements of the vector containing the
  text a .cmd-file can be created which can be
  used for calling jags in batch mode. 
}
\value{
  An object of class \code{JAGScontrol} is returned which is a list
  containing the following components: 
  \item{text}{a vector of strings which contains all
    commands for running jags. For creating a .cmd-file the prefix of
    the files has to be inserted.}
  \item{variables}{a vector containing the names of the monitored
    variables.} 
}
\author{Bettina Gruen}
\seealso{\code{\link{JAGSrun}}}
\examples{
control <- JAGScontrol(variables = "mu")
control
}
\keyword{utilities}


\eof
\name{JAGSread}
\alias{JAGSread}
\title{Reads jags output into R}
\description{
  Given an exit status of 0 when running jags the results are read in
  with \code{read.jags}
}
\usage{
JAGSread(exit, transform = TRUE)
}
\arguments{
  \item{exit}{exit status returned by \code{JAGScall}.}
  \item{transform}{logical: if \code{TRUE} and possible, the variable
    \eqn{\tau} is transformed into \eqn{\sigma^2}.}  
}
\details{
  After a successful run of jags the results are read in from the file
  "jags.out". If the exit status is positive the file "jags.dump" is
  read in and a warning is given. 
}
\value{
  A list with the following components is returned:
  \item{results}{MCMC chains.}
  \item{variables}{new variable names.}
}
\author{Bettina Gruen}
\seealso{\code{read.jags}, \code{\link{JAGSrun}}}
\keyword{utilities}


\eof
\name{JAGSrun}
\alias{JAGSrun}
\alias{print.jags}
\alias{jags}
\title{MCMC sampling of Bayesian models}
\description{
  Calls jags for MCMC sampling.
}
\usage{
JAGSrun(y, prefix = yname, model = BMMmodel(k = 2),
        control = JAGScontrol(variables = c("mu", "tau", "eta")), tmp = TRUE,
        cleanup = TRUE, jags = getOption("jags.exe"), ...)
}
\arguments{
  \item{y}{a numeric vector.}
  \item{prefix}{character prefix of files.}
  \item{model}{object of class \code{JAGSmodel} or output from \code{BMMmodel}.}
  \item{control}{specification of control by a \code{JAGScontrol} object.}
  \item{tmp}{logical: shall the files be written in a temporary directory.}
  \item{cleanup}{logical: shall the created files be removed.}
  \item{jags}{string indicating location of jags executable.}
  \item{yname}{a character string with the actual \code{y} argument name.}
  \item{...}{further parameters handed over to \code{BMMmodel} where it
    is used for the function specifiying the initial values, e.g.,
    \code{initsFS}.} 
}
\details{
  If an error occurs when runing jags, the created files are not
  removed. This function is a wrapper calling \code{JAGSsetup},
  \code{JAGScall} and \code{JAGSread}.
}
\value{
  Returns a \code{jags} object with components
  \item{call}{the matched call.}
  \item{results}{results read in from ``jags.out'' if run was successful
    or from ``jags.dump'' if an error occurred.}
  \item{model}{a \code{JAGSmodel} object.}
  \item{variables}{vector containing the names of the monitored variables.}
  \item{data}{a numeric vector.}
}
\author{Bettina Gruen}
\seealso{\code{\link{JAGSsetup}}, \code{\link{JAGScall}},
  \code{\link{JAGSread}}, \code{\link{BMMmodel}}, \code{\link{initsFS}}}
\examples{
data(fish)
prefix <- "fish"
variables <- c("mu","tau","eta")
k <- 3
modelFish <- BMMmodel(k = k, priors = list(kind = "independence",
                      parameter = "priorsFish", hierarchical = "tau"))
controlFish <- JAGScontrol(variables = c(variables, "S"), draw = 100, seed = 1)
## Installation of JAGS necessary for applying these functions
if (haveJAGS()) {
z1 <- JAGSrun(fish, prefix, model = modelFish, initialValues = list(S0 = 2),
              control = controlFish, cleanup = TRUE, tmp = FALSE)
zSort <- Sort(z1, "mu")
BMMposteriori(zSort)
}
data(darwin)
prefix <- "darwin"
k <- 2
modelDarwin <- BMMmodel(k = k, priors = list(kind = "independence",
                        parameter = "priorsUncertain"), aprioriWeights = c(1, 15),
                        no.empty.classes = TRUE, restrict = "tau")
## Installation of JAGS necessary for applying these functions
if (haveJAGS()) {
z2 <- JAGSrun(darwin, prefix, model = modelDarwin, control =
              JAGScontrol(variables = variables, draw = 3000, burnIn = 1000,
              seed = 1), cleanup = TRUE, tmp = FALSE)
plot(z2, variables = "mu")
}
}
\keyword{utilities}


\eof
\name{JAGSsetup}
\alias{JAGSsetup}
\alias{JAGSsetup.default}
\alias{JAGSsetup.BMMsetup}
\title{Creation of necessary input files for jags}
\description{
  Given the model and the control specifications the input files (.bug,
  -data.R, -inits.R, .cmd) for jags are created with \code{prefix} as
  their names.
}
\usage{
JAGSsetup(model, y, prefix, control, ...)

\method{JAGSsetup}{default}(model, y, prefix, control, ...)
\method{JAGSsetup}{BMMsetup}(model, y, prefix, control, ...)
}
\arguments{
  \item{model}{\code{JAGSmodel} object or output from \code{BMMmodel}.}
  \item{y}{a numeric vector.}
  \item{prefix}{string: prefix for .bug, -data.R, -inits.R and .cmd-file.}
  \item{control}{named list or \code{JAGScontrol} object.}
  \item{\dots}{additional parameters handed over to \code{BMMmodel}.}
}
\details{
  \code{control} needs to have a component \code{text} which is written
  into the .cmd file after inserting the \code{prefix} where necessary. 

}
\value{
  After creating the files \code{prefix}"-data.R",
  \code{prefix}"-inits.R", \code{prefix}".bug" and \code{prefix}".cmd"
  it returns a list with the following components
  \item{control}{input argument \code{control} with \code{prefix}
    inserted in the component\code{text}.}
  \item{model}{\code{JAGSmodel} object}
}
\author{Bettina Gruen}
\seealso{\code{\link{BMMmodel}}, \code{\link{JAGScontrol}}}
\keyword{utilities}

\eof
\name{Sort}
\alias{Sort}
\title{Sorts MCMC chains according to certain variables}
\description{Ascending sorting of results of \code{jags} object with
  model of class \code{BMMmodel} with respect to a given variable. 
}
\usage{
Sort(x, by = NULL)
}
\arguments{
  \item{x}{a \code{jags} object with model of class \code{BMMmodel}.}
  \item{by}{variable name according to which the segments shall be
    ordered.}
}
\details{If \code{by} is not specified, the first variable in the
  corresponding vector of the \code{jags} object is taken.
}
\value{
  The input object with results sorted in ascending order according
  to the variable given in \code{by} is returned.  
}
\author{Bettina Gruen}
\section{Warning}{If there arise problems, the original object is
  returned with a warning.}
\keyword{utilities}


\eof
\name{darwin}
\alias{darwin}
\docType{data}
\title{Differences in heights between plants}
\description{
  A numeric vector containing 15 observations of differences in heights
  between pairs of self-fertilized and cross-fertilized plants grown in
  the same condition.
}
\usage{data(darwin)}
\format{A numeric vector of length 15.
}
\details{
  Darwin's data set contains two extremely small values. Therefore, this
  data set can be used for outlier modelling.

}
\source{
  Abraham, B. and G. Box (1978)
  Linear models and spourious observations.
  \emph{Applied Statistics}, \bold{27}, 131--8.  
}
\examples{
data(darwin)
## Estimated sample density
plot(density(darwin[[1]]), ylim = c(0, 0.02), main = "Outlier modelling")
ss <- seq(-100, 100, by = 1)
## Normal density with estimated mean and sd of whole sample
lines(ss, dnorm(ss, mean = mean(darwin), sd = sd(darwin)), col = "red")
## Normal density with estimated mean and sd of sample, where the 2
## extremely small values are removed
lines(ss, dnorm(ss, mean = mean(darwin[-c(1:2),1]), sd = sd(darwin[-c(1:2),1])),
      col = "green")
}
\keyword{datasets}


\eof
\name{fish}
\alias{fish}
\docType{data}
\title{Fish length data}
\description{
  A numeric vector containing 256 observations of fish lengths.
}
\usage{data(fish)}
\format{A numeric vector of length 256.
}
\details{This data set can be used for modeling unobserved
  heterogeneity, as it can be assumed that underlying categories
  present in the data are the age groups to which the fish belong.  
}
\source{
  D. M. Titterington, A. F. M. Smith and U.E. Makov (1985)
  \emph{Statistical Analysis of Finite Mixture Distributions.}
  Wiley.
}
\examples{
data(fish)
ss <- seq(-3, 13, by = 0.01)
hist(fish[[1]], 20, freq = FALSE, main = "Fish data")
lines(ss, dnorm(ss, mean(fish), sd(fish)), col = "red")
}
\keyword{datasets}


\eof
\name{haveJAGS}
\alias{haveJAGS}
\title{Checks the availability of jags}
\description{
  Given the location of the jags executable, it is checked if it can be
  successfully called.
}
\usage{
haveJAGS(jags = getOption("jags.exe"))
}
\arguments{
  \item{jags}{string indicating location of jags executable. If
    \code{NULL} it is assumed that jags is in the search path.}
}
\value{
  Returns a logical.
}
\author{Bettina Gruen}
\keyword{utilities}


\eof
\name{initsFS}
\alias{initsFS}
\title{create initial values}
\description{
  Initial values for nodes are created after the suggestion in Sylvia
  Fruehwirth-Schnatter's book.
}
\usage{
initsFS(x, k, restrict, initialValues = list())
}
\arguments{
  \item{x}{a numeric vector.}
  \item{k}{number of segments.}
  \item{initialValues}{additional inital values specifications.}
  \item{restrict}{one of "none", "mu", "tau".}
}
\details{
  The initial values for \eqn{\mu} are determined by the quantiles of
  the data, those for \eqn{\eta} give equal weight on each segment and
  those for \eqn{\tau} are equal for all segments and estimated by the
  inverse of the IQR of the data devided by 1.34 and squared.
}
\value{
  A list with initial values for the parameter indicated by the
  name of the respective list element is returned. 
}
\author{Bettina Gruen}
\keyword{utilities}% at least one, from doc/KEYWORDS


\eof
\name{plot.BMMposteriori}
\alias{plot.BMMposteriori}
\title{Plots a posteriori probabilites of data points}
\description{
  Plot method for object of class \code{BMMposteriori}, typically
  called by \code{BMMposteriori}.
}
\usage{
\method{plot}{BMMposteriori}(x, caption, main = "", ...)
}
\arguments{
  \item{x}{a \code{BMMposteriori} object.}
  \item{caption}{captions to appear above the plots.}
  \item{main}{title to each plot-in addition to the above \code{caption}.}
  \item{\dots}{further graphical parameters may also be supplied as
    arguments.} 
}
\details{
  This function is called by \code{BMMposteriori} if \code{plot =
    TRUE}. 
}
\author{Bettina Gruen}

\seealso{\code{\link{BMMposteriori}}}
\keyword{hplot}


\eof
\name{plot.jags}
\alias{plot.jags}
\title{Plot jags Object}
\description{
  Plots \code{mcmc} chains of a \code{jags} object.
}
\usage{
\method{plot}{jags}(x, variables = NULL, trace = TRUE, density = TRUE,
smooth = TRUE, bwf, num, xlim, auto.layout = TRUE, ask = interactive(), ...)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{x}{a \code{jags} object.}
  \item{variables}{names of variables which shall be plotted. Default
    are all names of results except those with a column dimension larger
    than the number of classes \code{k}.}
  \item{trace}{plot trace of each variable.}
  \item{density}{plot density estimate of each variable.}
  \item{smooth}{draw a smooth line through trace plots.}
  \item{bwf}{bandwidth function for density plots.}
  \item{num}{if not all classes of a variable shall be plotted, a subset
    can be specified.}
  \item{xlim}{if not specified, the range of each variable over all
    classes is taken as default.}
  \item{auto.layout}{automatically generate output format.}
  \item{ask}{prompt user before each page of plots.}
  \item{\dots}{further arguments for \code{densityplot}.}
}
\details{
  Adapted from \code{plot.mcmc}.

  Currently only implemented for \code{jags} objects with model of class
  \code{BMMmodel}. Otherwise the default plot method for the \code{results}
  of the \code{jags} object is called (\code{plot.mcmc}).
}
\author{Bettina Gruen}
\seealso{\code{plot.mcmc}, \code{\link{BMMdiag}},
  \code{\link{BMMposteriori}}}
\keyword{hplot}


\eof
\name{priors}
\alias{priorsFish}
\alias{priorsRaftery}
\alias{priorsUncertain}
\title{Creates list of prior specifications}
\description{Given the data values for the priors are determined.
}
\usage{
priorsFish(y)
priorsRaftery(y)
priorsUncertain(y)

}
\arguments{
  \item{y}{a numeric vector.}
}
\details{Values for the prior parameter \code{b0}, \code{B0}, \code{nu0}
  and \code{S0} are determined.
}
\value{
  There is a list returned with named components of the prior parameters.
}
\author{Bettina Gruen}
\keyword{utilities}


\eof
\name{randomPermutation}
\alias{randomPermutation}
\title{Randomly permute segments for MCMC draws}
\description{
  Random permutation of segment labels for each draw in order to get a
  better estimate of the unrestricted likelihood.
}
\usage{
randomPermutation(x)
}
\arguments{
  \item{x}{a \code{jags} object with model of class \code{BMMmodel}.}
}
\details{
  The draws are permuted with respect to the different classes
  \code{k}. 
}
\value{
  The input object with permuted results for each draw is returned.
}
\author{Bettina Gruen}
\section{Warning}{Any variables where there are neither \code{k}
  different chains nor only one chain observed are dropped.} 
\keyword{utilities}



\eof
